var canvas = document.getElementById("cvGame");
var ctx = canvas.getContext("2d");
var game = {
    states: Object.freeze({"start": 0, "running":1, "over": 2,"end" : 3}),
    speed: 50,
    state: null,
    tmr: null,
    gravity: 0.75,
    jump: -14,
    shiftDown: false,
    leftDown: false,
    rightDown: false,
    ctrlDown: false,
    cash: 0
};
game.addCash = function(val){
    this.cash += val;
    document.getElementById("lblcc").textContent = this.cash;
};
var objects = {
    platforms: [],
    water: [],
    stops: [],
    things: [],
    coins: [],
    spiders: []
};
objects.animate = function(){
    for(let groups in this){
        let list = this[groups];
        for(let i = 0; i < list.length; i++){
            list[i].animate();
        }
    }
};
var sounds = {
    coin: new Audio("audio/coin.wav"),
    splash:  new Audio("audio/splash.wav")
};
function keyPressed(e) {
    switch (game.state){
       case game.states.start:
           break;
       case game.states.running:
            switch(e.keyCode){
                case 32:
                case 38:
                    character.jump();
                    break;
                case 37:
                    game.leftDown = true;
                    break;
                case 39:
                    game.rightDown = true;
                    break;
                case 17:
                    game.ctrlDown = true;
                    break;
                case 16:
                    game.shiftDown = true;
            }
            break;
        case game.states.end:
           break;
    }
}
function keyReleased(e) {
    switch(e.keyCode) {
        case 16:
            game.shiftDown = false;
            break;
        case 17:
            game.ctrlDown = false;
            break;
        case 37:
            game.leftDown = false;
            break;
        case 39:
            game.rightDown = false;
            break;
    }
}
function bump(rectA, rectB){
    return Math.max(rectA.x, rectB.x) < Math.min(rectA.x + rectA.width, rectB.x + rectB.width) &&
        Math.max(rectA.y, rectB.y) < Math.min(rectA.y + rectA.height, rectB.y + rectB.height);
}

function setSounds(){
    for(let aud in sounds){
        sounds[aud].onended = function(){
            this.currentTime = 0;
        };
    }
}
function drawFrame() {
    ctx.clearRect(0, 0, canvas.width, canvas.height);
    Background.animate();
    objects.animate();
    character.animate();
}
function initialise() {
    canvas.width = 800;
    canvas.height = 500;
    buildCharacter();
    Level.build();
    addBackgrounds();
    setSounds();
    window.addEventListener("keydown", keyPressed);
    window.addEventListener("keyup", keyReleased);
    game.state = game.states.running; // testing
    game.tmr = setInterval(drawFrame, game.speed);
}
initialise();